@@ -15,7 +15,7 @@ $LYNX = "NO";
 $GREP = "/bin/grep";
 $RECODE = "NO"; #"/usr/bin/recode"; -- dont use recode, it is not widely available
 # Directories
-$prefix="/usr/local";
+$prefix="/home/cs/usr";
 $datadir="${prefix}/share";
 $pkgdatadir="$datadir/ktoblzcheck";
 $BANKDATADIR="${pkgdatadir}";
@@ -38,7 +38,6 @@ $debug=0; # set this to nonzero for activating debugging mode
 $BASE_URL="http://www.bundesbank.de";
 $MAIN_URL="$BASE_URL/zahlungsverkehr";
 $MAIN_DOC="$MAIN_URL/zahlungsverkehr_bankleitzahlen_download.php";
-$INSTALLED_NAME="bankdata.txt";
 
 if ($debug == 0) {
   if ($WGET ne "NO") {
@@ -111,6 +110,12 @@ if (scalar @diff == 0) {
 ($correct_url_line) = grep (m|$file|, @potential_urls);
 ($correct_url) = ($correct_url_line =~ m|([^"]*$file[^"]*)|gio);
 
+# The installation name is now taken from the original filename;
+# "blz_20110102" will be installed after conversion as
+# "bankdata_20110102".
+$INSTALLED_NAME = $file;
+$INSTALLED_NAME =~ s/blz/bankdata/gio;
+
 $download = "$MAIN_URL/$correct_url";
 $install_1 = "$BANKDATADIR/$file";
 $install_2 = "$BANKDATADIR/$INSTALLED_NAME";
